<?php
/**
 * ukrainian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Oleksiy Voronin <ovoronin@gmail.com>
 * @author serg_stetsuk@ukr.net
 * @author Oleksandr Kunytsia <okunia@gmail.com>
 * @author Uko <uko@uar.net>
 * @author Ulrikhe Lukoie  <lukoie@gmail.com>
 * @author Kate Arzamastseva pshns@ukr.net
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Редагувати';
$lang['btn_source']            = 'Показати вихідний текст';
$lang['btn_show']              = 'Показати сторінку';
$lang['btn_create']            = 'Створити сторінку';
$lang['btn_search']            = 'Пошук';
$lang['btn_save']              = 'Зберегти';
$lang['btn_preview']           = 'Перегляд';
$lang['btn_top']               = 'Повернутися наверх';
$lang['btn_newer']             = '<< більш нові';
$lang['btn_older']             = 'більш старі >>';
$lang['btn_revs']              = 'Старі ревізії';
$lang['btn_recent']            = 'Останні зміни';
$lang['btn_upload']            = 'Завантажити';
$lang['btn_cancel']            = 'Скасувати';
$lang['btn_index']             = 'Зміст';
$lang['btn_secedit']           = 'Редагувати';
$lang['btn_login']             = 'Увійти';
$lang['btn_logout']            = 'Вийти';
$lang['btn_admin']             = 'Керування';
$lang['btn_update']            = 'Оновити';
$lang['btn_delete']            = 'Видалити';
$lang['btn_back']              = 'Назад';
$lang['btn_backlink']          = 'Посилання сюди';
$lang['btn_backtomedia']       = 'Назад до вибору медіа-файлу';
$lang['btn_subscribe']         = 'Підписатися';
$lang['btn_profile']           = 'Оновити профіль';
$lang['btn_reset']             = 'Очистити';
$lang['btn_draft']             = 'Редагувати чернетку';
$lang['btn_recover']           = 'Відновити чернетку';
$lang['btn_draftdel']          = 'Знищити чернетку';
$lang['btn_revert']            = 'Відновити';
$lang['btn_register']          = 'Реєстрація';
$lang['btn_apply']             = 'Застосувати';
$lang['loggedinas']            = 'Ви';
$lang['user']                  = 'Користувач';
$lang['pass']                  = 'Пароль';
$lang['newpass']               = 'Новий пароль';
$lang['oldpass']               = 'Поточний пароль';
$lang['passchk']               = 'ще раз';
$lang['remember']              = 'Запам\'ятати мене';
$lang['fullname']              = 'Повне ім\'я';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Профіль користувача';
$lang['badlogin']              = 'Вибачте, невірне ім\'я чи пароль.';
$lang['minoredit']             = 'Незначні зміни';
$lang['draftdate']             = 'Чернетка збережена';
$lang['nosecedit']             = 'Сторінку змінено, дані розділу застарілі. Завантажено сторінку повністю.';
$lang['regmissing']            = 'Необхідно заповнити всі поля.';
$lang['reguexists']            = 'Користувач з таким іменем вже існує.';
$lang['regsuccess']            = 'Користувача створено. Пароль відправлено на e-mail.';
$lang['regsuccess2']           = 'Користувача створено.';
$lang['regmailfail']           = 'При відправленні пароля сталась помилка. Зв’яжіться з адміністратором!';
$lang['regbadmail']            = 'Схоже, що адреса e-mail невірна - якщо ви вважаєте, що це помилка, зв’яжіться з адміністратором';
$lang['regbadpass']            = 'Надані паролі не співпадають, спробуйте ще раз.';
$lang['regpwmail']             = 'Пароль ДокуВікі';
$lang['reghere']               = 'Ще не маєте облікового запису? Отримайте його негайно';
$lang['profna']                = 'Ця Вікі не підтримує зміни профілю';
$lang['profnochange']          = 'Немає змін, немає що робити.';
$lang['profnoempty']           = 'Ім’я або e-mail не можуть бути пустими.';
$lang['profchanged']           = 'Профіль успішно змінено.';
$lang['pwdforget']             = 'Забули пароль? Отримайте новий';
$lang['resendna']              = 'Ця Вікі не підтримує повторне відправлення пароля.';
$lang['resendpwdmissing']      = 'Необхідно заповнити усі поля.';
$lang['resendpwdnouser']       = 'Такий користувач не існує.';
$lang['resendpwdbadauth']      = 'Код автентифікації невірний. Перевірте, чи ви використали повне посилання для підтвердження.';
$lang['resendpwdconfirm']      = 'Посилання для підтвердження відіслано на e-mail.';
$lang['resendpwdsuccess']      = 'Новий пароль відіслано на e-mail.';
$lang['license']               = 'Якщо не вказано інше, вміст цієї Вікі підпадає під дію такої ліцензії:';
$lang['licenseok']             = 'Примітка. Редагуючи ці сторінку, ви погоджуєтесь на розповсюдження інформації за такою ліцензією:';
$lang['searchmedia']           = 'Пошук файлу:';
$lang['searchmedia_in']        = 'Шукати у %s';
$lang['txt_upload']            = 'Виберіть файл для завантаження';
$lang['txt_filename']          = 'Завантажити як (не обов\'язкове)';
$lang['txt_overwrt']           = 'Перезаписати існуючий файл';
$lang['lockedby']              = 'Заблоковано';
$lang['lockexpire']            = 'Блокування завершується в';
$lang['js']['willexpire']      = 'Блокування редагування цієї сторінки закінчується через хвилину.\n Щоб уникнути конфліктів використовуйте кнопку перегляду для продовження блокування.';
$lang['js']['notsavedyet']     = 'Незбережені зміни будуть втрачені.
 Дійсно продовжити?';
$lang['js']['searchmedia']     = 'Шукати файли';
$lang['js']['keepopen']        = 'Тримати вікно відкритим під час вибору';
$lang['js']['hidedetails']     = 'Сховати деталі';
$lang['js']['mediatitle']      = 'Налаштунки посилання';
$lang['js']['mediadisplay']    = 'Тип посилання';
$lang['js']['mediaalign']      = 'Вирівнювання';
$lang['js']['mediasize']       = 'Розмір зображення';
$lang['js']['mediatarget']     = 'Ціль посилання';
$lang['js']['mediaclose']      = 'Закрити';
$lang['js']['mediainsert']     = 'Вставити';
$lang['js']['mediadisplayimg'] = 'Показати зображення.';
$lang['js']['mediadisplaylnk'] = 'Показати тільки посилання.';
$lang['js']['mediasmall']      = 'Зменшена версія';
$lang['js']['mediamedium']     = 'Середня версія';
$lang['js']['medialarge']      = 'Велика версія';
$lang['js']['mediaoriginal']   = 'Оригінальна версія';
$lang['js']['medialnk']        = 'Посилання на сторінку з описом';
$lang['js']['mediadirect']     = 'Пряме посилання на оригінал';
$lang['js']['medianolnk']      = 'Немає посилання';
$lang['js']['medianolink']     = 'Не посилайтеся на зображення';
$lang['js']['medialeft']       = 'Вирівняти зображення по лівому краю.';
$lang['js']['mediaright']      = 'Вирівняти зображення по правому краю.';
$lang['js']['mediacenter']     = 'Вирівняти зображення по центру.';
$lang['js']['medianoalign']    = 'Не вирівнювати зображення.';
$lang['js']['nosmblinks']      = 'Посилання на мережеві папки працює лише в Internet Explorer.
Ви можете скопіювати посилання і відкрити його за допомогою Internet Explorer.';
$lang['js']['linkwiz']         = 'Чарівник посилань';
$lang['js']['linkto']          = 'Посилання на:';
$lang['js']['del_confirm']     = 'Дійсно знищити обрані елементи?';
$lang['rssfailed']             = 'Виникла помилка під час отримання RSS-стрічки: ';
$lang['nothingfound']          = 'Нічого не знайдено.';
$lang['mediaselect']           = 'Вибір медіа-файлу';
$lang['fileupload']            = 'Завантаження медіа-файлу';
$lang['uploadsucc']            = 'Завантаження пройшло успішно';
$lang['uploadfail']            = 'Помилка при завантаженні. Можливо неправильні права?';
$lang['uploadwrong']           = 'Завантаження заборонено. Таке розширення файлу не дозволяється!';
$lang['uploadexist']           = 'Файл вже існує. Нічого не зроблено.';
$lang['uploadbadcontent']      = 'Завантажений вміст не відповідає розширенню %s.';
$lang['uploadspam']            = 'Завантаження заблоковано спам-фільтром.';
$lang['uploadxss']             = 'Завантаження заблоковано через можливість злонаміреного вмісту.';
$lang['uploadsize']            = 'Завантажений файл надто великий (максимум %s).';
$lang['deletesucc']            = 'Файл "%s" знищено.';
$lang['deletefail']            = 'Неможливо знищити "%s" - перевірте права доступу.';
$lang['mediainuse']            = '"%s" не знищено - файл використовується.';
$lang['namespaces']            = 'Простори імен';
$lang['mediafiles']            = 'Доступні файли';
$lang['accessdenied']          = 'Вам не дозволено переглядати цю сторінку.';
$lang['mediausage']            = 'Для посилання на цей файл використовуйте такий синтаксис:';
$lang['mediaview']             = 'Переглянути початковий файл';
$lang['mediaroot']             = 'корінь';
$lang['mediaupload']           = 'Завантаження файлу у поточний простір імен. Щоб створити простори імен, додайте їх в початок імені файлу та розділіть двокрапками.';
$lang['mediaextchange']        = 'Розширення файлу змінено з .%s на .%s!';
$lang['reference']             = 'Посилання для';
$lang['ref_inuse']             = 'Цей файл не може бути знищено, оскільки він використовується такими сторінками:';
$lang['ref_hidden']            = 'Деякі посилання існують на сторінках, для читання яких у вас немає прав.';
$lang['hits']                  = 'Збіги';
$lang['quickhits']             = 'Збіги у назвах сторінок';
$lang['toc']                   = 'Зміст';
$lang['current']               = 'поточний';
$lang['yours']                 = 'Ваша версія';
$lang['diff']                  = 'показати відмінності від поточної версії';
$lang['diff2']                 = 'Показати відмінності між вибраними версіями';
$lang['difflink']              = 'Посилання на цей список змін';
$lang['diff_type']             = 'Переглянути відмінності:';
$lang['diff_inline']           = 'Вбудувати';
$lang['diff_side']             = 'Поряд';
$lang['line']                  = 'Рядок';
$lang['breadcrumb']            = 'Відвідано';
$lang['youarehere']            = 'Ви тут';
$lang['lastmod']               = 'В останнє змінено';
$lang['by']                    = ' ';
$lang['deleted']               = 'знищено';
$lang['created']               = 'створено';
$lang['restored']              = 'відновлено стару ревізію';
$lang['external_edit']         = 'зовнішнє редагування';
$lang['summary']               = 'Підсумок змін';
$lang['noflash']               = 'Для перегляду цієї сторінки необхідно встановити <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
$lang['download']              = 'Завантажити фрагмент';
$lang['mail_newpage']          = 'сторінку додано:';
$lang['mail_changed']          = 'сторінку змінено:';
$lang['mail_subscribe_list']   = 'сторінки, що змінено у просторі імен:';
$lang['mail_new_user']         = 'новий користувач:';
$lang['mail_upload']           = 'завантажено файл:';
$lang['qb_bold']               = 'Напівжирний текст';
$lang['qb_italic']             = 'Курсив';
$lang['qb_underl']             = 'Підкреслений текст';
$lang['qb_code']               = 'Текст коду';
$lang['qb_strike']             = 'Закреслений текст';
$lang['qb_h1']                 = 'Заголовок 1-го рівня';
$lang['qb_h2']                 = 'Заголовок 2-го рівня';
$lang['qb_h3']                 = 'Заголовок 3-го рівня';
$lang['qb_h4']                 = 'Заголовок 4-го рівня';
$lang['qb_h5']                 = 'Заголовок 5-го рівня';
$lang['qb_h']                  = 'Заголовок';
$lang['qb_hs']                 = 'Вибрати заголовок';
$lang['qb_hplus']              = 'Заголовок вищого рівня';
$lang['qb_hminus']             = 'Заголовок нищого рівня';
$lang['qb_hequal']             = 'Заголовок того ж рівня';
$lang['qb_link']               = 'Внутрішнє посилання';
$lang['qb_extlink']            = 'Зовнішнє посилання';
$lang['qb_hr']                 = 'Роздільник';
$lang['qb_ol']                 = 'Елемент нумерованого списку';
$lang['qb_ul']                 = 'Елемент ненумерованого списку';
$lang['qb_media']              = 'Додати зображень та інші файли';
$lang['qb_sig']                = 'Додати підпис';
$lang['qb_smileys']            = 'Посмішки';
$lang['qb_chars']              = 'Спеціальні символи';
$lang['upperns']               = 'Перейти до батьківського простору імен';
$lang['admin_register']        = 'Додати нового користувача';
$lang['metaedit']              = 'Редагувати метадані';
$lang['metasaveerr']           = 'Помилка запису метаданих';
$lang['metasaveok']            = 'Метадані збережено';
$lang['img_backto']            = 'Повернутися до';
$lang['img_title']             = 'Назва';
$lang['img_caption']           = 'Підпис';
$lang['img_date']              = 'Дата';
$lang['img_fname']             = 'Ім’я файлу';
$lang['img_fsize']             = 'Розмір';
$lang['img_artist']            = 'Фотограф';
$lang['img_copyr']             = 'Авторські права';
$lang['img_format']            = 'Формат';
$lang['img_camera']            = 'Камера';
$lang['img_keywords']          = 'Ключові слова';
$lang['subscr_subscribe_success'] = 'Додано %s до списку підписки для %s';
$lang['subscr_subscribe_error'] = 'Помилка при додавані %s до списку підписки для %s';
$lang['subscr_subscribe_noaddress'] = 'Немає адреси, асоційованої з Вашим логіном, тому Ви не можете бути додані до списку підписки.';
$lang['subscr_unsubscribe_success'] = 'Видалено %s із списку підписки для %s';
$lang['subscr_unsubscribe_error'] = 'Помилка при видаленні %s зі списку підписки для %s';
$lang['subscr_already_subscribed'] = '%s вже підписаний до %s';
$lang['subscr_not_subscribed'] = '%s не підписаний до %s';
$lang['subscr_m_not_subscribed'] = 'Ви зараз не підписані до цієї сторінки або простору імен.';
$lang['subscr_m_new_header']   = 'Додати підписку';
$lang['subscr_m_current_header'] = 'Поточні підписки';
$lang['subscr_m_unsubscribe']  = 'Відписатися';
$lang['subscr_m_subscribe']    = 'Підписатися';
$lang['subscr_m_receive']      = 'Отримувати';
$lang['subscr_style_every']    = 'повідомляти на пошту про кожну зміну';
$lang['subscr_style_digest']   = 'лист з дайджестом для зміни кожної сторінки (кожні %.2f днів)';
$lang['subscr_style_list']     = 'список змінених сторінок від часу отримання останнього листа (кожні %.2f днів)';
$lang['authmodfailed']         = 'Неправильні налаштування автентифікації користувача. Будь ласка, повідомте про це адміністратора.';
$lang['authtempfail']          = 'Автентифікація користувача тимчасово не доступна. Якщо це буде продовжуватись, будь ласка, повідомте адміністратора.';
$lang['i_chooselang']          = 'Виберіть мову';
$lang['i_installer']           = 'Програма установки ДокуВікі';
$lang['i_wikiname']            = 'Назва Вікі';
$lang['i_enableacl']           = 'Дозволити використання ACL (рекомендовано)';
$lang['i_superuser']           = 'Суперкористувач';
$lang['i_problems']            = 'Програма установки знайшла декілька проблем, що вказані нижче. Ви не можете продовжити, поки не виправите їх';
$lang['i_modified']            = 'З причин безпеки цей скрипт буде працювати тільки з новою та немодифікованою установкою ДокуВікі.
Вам слід або ще раз розпакувати файли із завантаженого пакету, або звернутися до повної <a href="http://dokuwiki.org/install">інструкції з установки ДокуВікі</a>';
$lang['i_funcna']              = 'Функція PHP <code>%s</code> не доступна. Можливо, хостинг-провайдер відключив її з якихось причин?';
$lang['i_phpver']              = 'Версія PHP <code>%s</code> менша, ніж необхідно - <code>%s</code>. Необхідно оновити PHP.';
$lang['i_permfail']            = 'ДокуВікі не має прав на запис <code>%s</code>. Необхідно змінити права доступа для цієї папки!';
$lang['i_confexists']          = '<code>%s</code> вже існує';
$lang['i_writeerr']            = 'Неможливо створити <code>%s</code>. Необхідно перевірити права доступа для файлу/папки та створити файл вручну.';
$lang['i_badhash']             = 'Невпізнаний або модифікований dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - невірне або пусте значення.';
$lang['i_success']             = 'Налаштування завершено. Ви можете знищити файл install.php.
Перейдіть до <a href="doku.php">вашої нової ДокуВікі</a>';
$lang['i_failure']             = 'При збереженні файлу конфігурації виникли помилки. Можливо вам доведеться виправити їх самостійно
до початку використання <a href="doku.php">вашої нової ДокуВікі</a>.';
$lang['i_policy']              = 'Початкова політика ACL';
$lang['i_pol0']                = 'Відкрита Вікі (читання, запис та завантаження файлів для всіх)';
$lang['i_pol1']                = 'Публічна Вікі (читання для всіх, запис та завантаження для зареєстрованих користувачів)';
$lang['i_pol2']                = 'Закрита Вікі (читання, запис та завантаження тільки для зареєстрованих користувачів)';
$lang['i_retry']               = 'Повторити';
$lang['i_license']             = 'Будь ласка, виберіть тип ліцензії, під якою Ві бажаєте опублікувати матеріал:';
$lang['recent_global']         = 'Ви переглядаєте зміни в межах простору імен <b>%s</b>. Також можна <a href="%s">переглянути зміни в межах усієї Вікі</a>.';
$lang['years']                 = '%d років тому';
$lang['months']                = '%d місяців тому';
$lang['weeks']                 = '%d тижнів тому';
$lang['days']                  = '%d днів тому';
$lang['hours']                 = '%d годин тому';
$lang['minutes']               = '%d хвилин тому';
$lang['seconds']               = '%d секунд тому';
$lang['wordblock']             = 'Ваші зміни не збережено, тому що вони розпізнані як такі, що містять заблокований текст(спам).';
